@@ -40,7 +40,9 @@ class ApiHitAdmin(admin.ModelAdmin):
 
     def changelist_view(self, request, extra_context=None):
         extra_context = extra_context or {}
-        hit_data = ApiHitSerializer(instance=self.get_queryset(request), many=True).data
+        cl = self.get_changelist_instance(request)
+
+        hit_data = ApiHitSerializer(instance=cl.get_queryset(request), many=True).data
         extra_context['hits_json'] = JSONRenderer().render(hit_data).decode('utf-8')
 
         return super(ApiHitAdmin, self).changelist_view(request, extra_context=extra_context)
