@@ -7,6 +7,15 @@ QrKindTypes = [
     ('pdf', 'Pdf')
 ]
 
+QrFilenameChoices = [
+    ('title', 'title.ext'),
+    ('envtitle', 'env-title.ext'),
+    ('basic', 'basic_info.ext'),
+    ('envbasic', 'env-basic_info.ext'),
+    ('uuid', 'uuid.ext'),
+    ('envuuid', 'env-uuid.ext')
+]
+
 
 class HexField(forms.CharField):
     def __init__(self, **kwargs):
@@ -20,6 +29,7 @@ class QrGenerateForm(forms.Form):
     light = HexField(required=False, initial='#FFFFFF', widget=forms.TextInput(attrs={'type': 'color'}))
     dark = HexField(required=False, initial='#000000', widget=forms.TextInput(attrs={'type': 'color'}))
     scale = forms.IntegerField(required=False, initial=3)
+    filename = forms.ChoiceField(choices=QrFilenameChoices, required=False, initial='title')
 
     def clean_kind(self):
         if not self['kind'].html_name in self.data:
@@ -40,3 +50,8 @@ class QrGenerateForm(forms.Form):
         if not self['scale'].html_name in self.data:
             return self.fields['scale'].initial
         return self.cleaned_data['scale']
+
+    def clean_filename(self):
+        if not self['filename'].html_name in self.data:
+            return self.fields['filename'].initial
+        return self.cleaned_data['filename']
